diff --git a/modules/itop-config-mgmt-1.0.0/data.sample.Contact.xml b/modules/itop-config-mgmt-1.0.0/data.sample.Contact.xml
index 1ca5acd0e..cefce0dd6 100644
--- a/modules/itop-config-mgmt-1.0.0/data.sample.Contact.xml
+++ b/modules/itop-config-mgmt-1.0.0/data.sample.Contact.xml
@@ -1,6 +1,15 @@
-
+
+Picasso
+active
+2
+pablo@combodo.com
+
+3
+Pablo
+
+
Dali
active
2
diff --git a/modules/itop-service-mgmt-1.0.0/data.sample.Contract.xml b/modules/itop-service-mgmt-1.0.0/data.sample.Contract.xml
index 061917896..b465e0645 100644
--- a/modules/itop-service-mgmt-1.0.0/data.sample.Contract.xml
+++ b/modules/itop-service-mgmt-1.0.0/data.sample.Contract.xml
@@ -10,7 +10,7 @@
2
-1
+2
2
@@ -23,7 +23,7 @@
2
-1
+2
4
\ No newline at end of file
diff --git a/modules/itop-service-mgmt-1.0.0/data.sample.Service.xml b/modules/itop-service-mgmt-1.0.0/data.sample.Service.xml
index cf1461167..c6329e6bb 100644
--- a/modules/itop-service-mgmt-1.0.0/data.sample.Service.xml
+++ b/modules/itop-service-mgmt-1.0.0/data.sample.Service.xml
@@ -1,3 +1,17 @@
-
\ No newline at end of file
+
+2
+HW Management
+Hardware support and repair
+IncidentManagement
+production
+
+
+2
+NW Management
+LAN and WAN support and troubleshooting
+IncidentManagement
+production
+
+
diff --git a/setup/index.php b/setup/index.php
index fc96082da..47fd698cc 100644
--- a/setup/index.php
+++ b/setup/index.php
@@ -775,8 +775,12 @@ function ModulesSelection(SetupWebPage $oP, $aParamValues, $iCurrentStep, $oConf
$aSelectedModules = $aParamValues['module'];
if ($aSelectedModules == '')
{
// Make sure it gets initialized as an array
$aSelectedModules = array();
+ foreach($aAvailableModules as $sModuleId => $aModule)
+ {
+ $aSelectedModules[] = $sModuleId;
+ }
}
foreach($aAvailableModules as $sModuleId => $aModule)
{
@@ -775,8 +775,12 @@ function ModulesSelection(SetupWebPage $oP, $aParamValues, $iCurrentStep, $oConf
if ($aSelectedModules == '')
{
- // Make sure it gets initialized as an array
+ // Make sure it gets initialized as an array, default value: all modules selected !
$aSelectedModules = array();